@@ -21,10 +21,10 @@ from cubicweb.view import Adapter, EntityAdapter
 from cubicweb.predicates import match_kwargs, relation_possible, is_instance
 from cubicweb.entities import AnyEntity, fetch_config, authobjs, lib
 
+from .. import ark
 
-class ARKGeneratorMixIn(object):
-    """Entity adapter for ARK unique identifier generation"""
-    __abstract__ = True
+
+class ARKIdentifierGeneratorMixin(object):
     __regid__ = 'IARKGenerator'
     __select__ = match_kwargs('naa_what')
 
@@ -32,42 +32,74 @@ class ARKGeneratorMixIn(object):
         """Return a new ARK identifier as unicode"""
         return u'{0}/{1}'.format(self.cw_extra_kwargs['naa_what'], self.assign_name())
 
+
+class ARKIdentifierGenerator(ARKIdentifierGeneratorMixin, Adapter):
+    """Adapter for ARK unique identifier generation"""
+
     def assign_name(self):
         """Assign and return a new name part of the ARK identifier"""
-        raise NotImplementedError()
+        naan = int(self.cw_extra_kwargs['naa_what'])
+        return ark.generate_ark(self._cw, naan)
 
 
-class ARKExtIdentifierGenerator(ARKGeneratorMixIn, Adapter):
-    """Simple adapter for allocation of ark to object which are not (yet) entities."""
-
-    def assign_name(self):
-        """Return a new unique identifier as unicode"""
-        dbh = self._cw.repo.system_source.dbhelper
-        for sql in dbh.sqls_increment_sequence('ext_ark_count'):
-            cu = self._cw.system_sql(sql)
-        count = cu.fetchone()[0]
-        return u'a{0:09d}'.format(count)
-
-
-class ARKCWIdentifierGenerator(ARKGeneratorMixIn, Adapter):
-    """saem_ref.IARKGenerator entity adapter generating ARK like identifier during non-production
-    phase.
+class QualifiedARKIdentifierGenerator(ARKIdentifierGeneratorMixin, Adapter):
+    """Adapter for ARK identifier generation using a qualifier from an
+    existing "base" ARK identifier.
     """
-    __select__ = ARKGeneratorMixIn.__select__ & match_kwargs('eid', 'etype')
+    __abstract__ = True
+
+    @property
+    def parent_entity(self):
+        raise NotImplementedError
 
     def assign_name(self):
-        eid = self.cw_extra_kwargs['eid']
-        etype = self.cw_extra_kwargs['etype']
-        prefix = {
-            'AuthorityRecord': u'r',
-            'SEDAArchiveTransfer': u'p',
-            'Concept': u'c',
-            'ConceptScheme': u'v',
-            'Organization': u'o',
-            'Agent': u'oa',
-            'OrganizationUnit': u'ou',
-        }.get(etype, u'')
-        return u'{0}{1:09d}'.format(prefix, eid)
+        match = ark.match(self.parent_entity.ark)
+        if not match:
+            raise ValueError(
+                "ARK identifier for parent entity #%d looks malformattted: %s"
+                % (self.parent_entity.eid, self.parent_entity.ark)
+            )
+        naan = int(self.cw_extra_kwargs['naa_what'])
+        # Sanity check to make sure we're not producing ARK identifiers with
+        # different NAAN for entities that are supposed to be parent of each
+        # others.
+        if int(match.group('naan')) != naan:
+            raise ValueError(
+                "NAAN of parent entity ark:/%s does not match the value of "
+                "'naa_what' parameter: %s"
+                % (self.parent_entity.ark, naan)
+            )
+        name = match.group('name')
+        qualifier = ark.generate_qualified_ark(self._cw, naan, name)
+        return u'/'.join([name, qualifier])
+
+
+class ConceptARKIdentifierGenerator(QualifiedARKIdentifierGenerator):
+    __select__ = (
+        ARKIdentifierGeneratorMixin.__select__
+        & match_kwargs('in_scheme')
+    )
+
+    @property
+    def parent_entity(self):
+        scheme = self.cw_extra_kwargs['in_scheme']
+        if hasattr(scheme, 'eid'):
+            return scheme
+        return self._cw.entity_from_eid(scheme)
+
+
+class OUARKIdentifierGenerator(QualifiedARKIdentifierGenerator):
+    __select__ = (
+        ARKIdentifierGeneratorMixin.__select__
+        & match_kwargs('authority')
+    )
+
+    @property
+    def parent_entity(self):
+        authority = self.cw_extra_kwargs['authority']
+        if hasattr(authority, 'eid'):
+            return authority
+        return self._cw.entity_from_eid(authority)
 
 
 class ArkNAALocator(EntityAdapter):
@@ -111,16 +143,18 @@ class AgentArkNAALocator(ArkNAALocator):
 
 
 class ConceptArkNAALocator(ArkNAALocator):
-    """Return NAA for Concept, usually specified through a record in transaction data"""
+    """Return NAA for Concept, through the concept scheme which it belongs to."""
     __select__ = is_instance('Concept')
 
     def naa_what(self):
-        if 'concept_scheme' in self._cw.transaction_data:
-            scheme = self._cw.entity_from_eid(self._cw.transaction_data['concept_scheme'])
-            return scheme.cw_adapt_to(self.__regid__).naa_what()
-        elif self.entity.in_scheme:  # entity may not yet be related to its scheme
-            return self.entity.in_scheme[0].cw_adapt_to(self.__regid__).naa_what()
-        return None
+        # entity is usually not yet created, since ark has to be generated before entity creation
+        if 'in_scheme' in getattr(self.entity, 'cw_edited', {}):
+            scheme = self._cw.entity_from_eid(self.entity.cw_edited['in_scheme'])
+        elif self.entity.in_scheme:
+            scheme = self.entity.in_scheme[0]
+        else:
+            return None
+        return scheme.cw_adapt_to(self.__regid__).naa_what()
 
 
 class ExternalUri(AnyEntity):
