@@ -55,6 +55,24 @@ def agency_id(self, agency):
     return None if agency.agency is None else 'ark:/' + agency.agency.ark
 
 
+orig_xsd_transferring_agency_archive_identifier = \
+    SEDA1XSDExport.xsd_transferring_agency_archive_identifier
+
+
+@monkeypatch(SEDA1XSDExport)
+def xsd_transferring_agency_archive_identifier(self, parent, content_entity, tag_name):
+    if content_entity.transferring_agency_archive_unit_identifier:
+        # XXX should not happen since we hide the field (views/seda.py).
+        return orig_xsd_transferring_agency_archive_identifier(
+            self, parent, content_entity, tag_name)
+    # Insert an element with a "fixed value" (empty) that should be overridden
+    # by downstream consumers.
+    self.element_schema(
+        parent, tag_name, 'qdt:ArchiveIDType',
+        fixed_value='',
+        xsd_attributes=self.xsd_attributes_scheme())
+
+
 class SAEMSEDAArchiveTransferIClonableAdapter(SEDAArchiveTransferIClonableAdapter):
     __select__ = SEDAArchiveTransferIClonableAdapter.__select__ & is_in_state('published')
     rtype = 'new_version_of'
