@@ -17,6 +17,8 @@
 
 from datetime import datetime
 
+import psycopg2
+
 from logilab.common.registry import objectify_predicate
 
 from yams import ValidationError
@@ -29,7 +31,11 @@ from cubicweb.predicates import (is_instance, adaptable, on_fire_transition,
 from cubicweb.server import hook
 from cubicweb.hooks import metadata
 
-from cubes.skos.hooks import ReplaceExternalUriByEntityHook
+from cubicweb_skos.hooks import ReplaceExternalUriByEntityHook
+from .ark import (
+    match as ark_match,
+    insert_ark,
+)
 
 
 # skip relations involved in the logging itself and some others that should not
@@ -208,13 +214,26 @@ class AssignARKHook(hook.Hook):
             naa_what = self.entity.cw_adapt_to('IArkNAALocator').naa_what()
         else:
             naa_what = None
-        set_ark_and_cwuri(self._cw, self.entity.eid, self.entity.cw_etype,
-                          self.entity.cw_edited, naa_what=naa_what)
+        set_ark_and_cwuri(self._cw, self.entity.cw_edited, naa_what=naa_what)
 
 
-def set_ark_and_cwuri(cw, eid, etype, entity_attrs, naa_what=None):
+def set_ark_and_cwuri(cw, entity_attrs, naa_what=None):
     ark = entity_attrs.get('ark')
-    if not ark:
+    if ark:
+        m = ark_match(ark, external=True)
+        msg = _('malformatted ARK idenfitier %(ark)s (expecting [ark:/]NAAN/Name[Qualifier])')
+        msgargs = {'ark': ark}
+        if m is None:
+            raise ValidationError(None, {'ark': msg}, msgargs=msgargs)
+        matched = m.groupdict()
+        naan, name = matched.pop('naan'), matched.pop('name')
+        qualifier = matched.get('qualifier')
+        try:
+            ark = insert_ark(cw, naan, name, qualifier)
+        except psycopg2.IntegrityError:
+            raise ValidationError(
+                None, {'ark': _('%(ark)s already exists')}, msgargs={'ark': ark})
+    else:
         cwuri = entity_attrs.get('cwuri')
         ark = None if cwuri is None else extract_ark(cwuri)
         if ark is None:
@@ -222,10 +241,11 @@ def set_ark_and_cwuri(cw, eid, etype, entity_attrs, naa_what=None):
                 msg = _('an ARK identifier has to be generated but no Name Assigning Authority is '
                         'specified')
                 raise ValidationError(None, {None: msg})
-            generator = cw.vreg['adapters'].select('IARKGenerator', cw, eid=eid, etype=etype,
-                                                   naa_what=naa_what)
+            generator = cw.vreg['adapters'].select(
+                'IARKGenerator', cw,
+                naa_what=naa_what, **entity_attrs)
             ark = generator.generate_ark()
-        entity_attrs['ark'] = ark
+    entity_attrs['ark'] = ark
     if 'cwuri' not in entity_attrs:
         # store ark as cwuri, not an URL so it's easier to move the database while still easy to get
         # an URL from there (see the cwuri_url function) XXX (syt) any other reason to do so? there
@@ -445,6 +465,22 @@ class DepreciateProfileOnReplacePublishedHook(hook.Hook):
             wf.fire_transition_if_possible("deprecate")
 
 
+class UnlinkDeprecatedProfileFromOrganizationUnit(hook.Hook):
+    """Remove 'use_profile' relation of a SEDAArchiveTransfer when it gets
+    deprecated.
+    """
+    __select__ = (
+        hook.Hook.__select__
+        & on_fire_transition('SEDAArchiveTransfer', 'deprecate')
+    )
+    __regid__ = 'seda.unlink_deprecated_profile_from_organization_unit'
+    events = ('after_add_entity',)
+
+    def __call__(self):
+        self._cw.execute('DELETE O use_profile X WHERE X eid %(x)s',
+                         {'x': self.entity.for_entity.eid})
+
+
 # Relations deposit agent - archival agent  ####################################
 
 class DontDeleteUnitIfArchival(hook.Hook):
