@@ -25,7 +25,7 @@ from cubicweb.schema import (RO_ATTR_PERMS, ERQLExpression, RRQLExpression,
                              make_workflowable)
 from cubicweb.schemas.base import ExternalUri, EmailAddress
 
-from cubes.skos.schema import ConceptScheme
+from cubicweb_skos import schema as skos
 from cubicweb_prov import schema as prov
 from cubicweb_eac import schema as eac
 from cubicweb_seda.schema import simplified_profile
@@ -130,10 +130,13 @@ for etype_def in (eac.ChronologicalRelation,
     }
 
 
-# Customization of skos schema.
-make_workflowable(ConceptScheme)
-publication_permissions(ConceptScheme, groups=('managers',))
-ConceptScheme.__permissions__['add'] = ('managers',)
+# SKOS #########################################################################
+
+make_workflowable(skos.ConceptScheme)
+publication_permissions(skos.ConceptScheme, groups=('managers',))
+skos.ConceptScheme.__permissions__['add'] = ('managers',)
+
+skos.in_scheme.cardinality = '1*'
 
 
 class Organization(EntityType):
@@ -483,6 +486,11 @@ class new_version_of(RelationDefinition):
 
 
 def post_build_callback(schema):
+    # Make "in_scheme" relation type inlined so that it gets considered
+    # directly (as attributes) during dataimport to help ARK identifier
+    # generation.
+    schema['in_scheme'].inlined = True
+
     schema['simplified_profile'].rdefs['SEDAArchiveTransfer', 'Boolean'].default = True  # XXX
     from . import ConceptSchemeGraph
     graph = ConceptSchemeGraph(schema)
