@@ -17,14 +17,17 @@
 
 from cubicweb.web.views import uicfg
 
-from cubicweb_seda.views import archivetransfer
+from cubicweb_seda.views import (
+    CONTENT_ETYPE,
+    archivetransfer,
+    archiveunit,
+    rtags_from_rtype_role_targets,
+)
 
 
 afs = uicfg.autoform_section
 pvs = uicfg.primaryview_section
 
-afs.tag_attribute(('SEDAArchiveTransfer', 'simplified_profile'), 'main', 'hidden')
-
 # we want only simplified_profile, so its default is set to true and it only has to be hidden
 afs.tag_attribute(('SEDAArchiveTransfer', 'simplified_profile'), 'main', 'hidden')
 # also hide transferring and archival agency
@@ -40,3 +43,19 @@ afs.tag_attribute(('SEDABinaryDataObject', 'filename'), 'main', 'hidden')
 
 
 archivetransfer.ArchiveTransferTabbedPrimaryView.tabs.append('saem.lifecycle_tab')
+
+
+# Hide "identifiant pour le service versant" which should be automatically
+# filled.
+class SimplifiedContentMainView(archiveunit.SimplifiedContentMainView):
+
+    rtype_role_targets = archiveunit.SimplifiedContentMainView.rtype_role_targets[:]
+    rtype_role_targets.remove(
+        ('seda_transferring_agency_archive_unit_identifier', 'object', None)
+    )
+    rsection, display_ctrl = rtags_from_rtype_role_targets(CONTENT_ETYPE, rtype_role_targets)
+
+
+def registration_callback(vreg):
+    vreg.register_all(globals().values(), __name__, [SimplifiedContentMainView])
+    vreg.register_and_replace(SimplifiedContentMainView, archiveunit.SimplifiedContentMainView)
