@@ -20,9 +20,9 @@ from cubicweb import tags, _
 from cubicweb.view import AnyRsetView
 from cubicweb.predicates import is_instance
 from cubicweb.web import formwidgets as fw
-from cubicweb.web.views import baseviews, treeview, uicfg, editcontroller
+from cubicweb.web.views import baseviews, treeview, uicfg
 
-from cubes.skos import views as skos
+from cubicweb_skos import views as skos
 
 from . import ImportEntityComponent
 
@@ -39,6 +39,15 @@ for etype, attr in (('ConceptScheme', 'ark'),
 _('Import ConceptScheme')  # generate message used by the import component
 
 
+# Have "in_scheme" inserted in attributes section so that it appears in
+# cw_edited and ARK generation hook works. (This overrides uicfg tag in
+# cubicweb-skos.)
+afs.tag_subject_of(('Concept', 'in_scheme', '*'), 'main', 'attributes')
+# Though we don't want to see the field as a Concept can only be created
+# through one ConceptScheme, so hide the widget.
+affk.set_field_kwargs('Concept', 'in_scheme', widget=fw.HiddenInput())
+
+
 class SKOSImportComponent(ImportEntityComponent):
     """Component with a link to import a concept scheme from a SKOS file."""
     __select__ = ImportEntityComponent.__select__ & is_instance('ConceptScheme')
@@ -105,33 +114,8 @@ class ConceptPopoverView(AnyRsetView):
         self.w(tags.a(title, href='javascript:$.noop();', id=str(entity.eid), **data))
 
 
-class SAEMEditController(editcontroller.EditController):
-
-    def edit_entity(self, formparams, multiple=False):
-        if formparams['__type'] == 'Concept' and not formparams['eid'].isdigit():
-            # concept is being created, attempt to find its parent scheme and set this in
-            # transaction data so it's reachable from hooks. This is necessary because some hook
-            # will use that to retrieve the ARK NAA that should be used to assign a ark to the newly
-            # created concept. This is really hackish, and could be avoided if in_scheme relation
-            # was inlined or if form data was available from the hook side.
-            for linkto in self._cw.list_form_param('__linkto'):
-                rtype, eid, target = linkto.split(':')
-                if rtype == 'in_scheme':
-                    self._cw.transaction_data['concept_scheme'] = eid
-                    break
-            else:
-                # not found, search in form params
-                for param, value in formparams.items():
-                    if param == 'in_scheme-subject':
-                        self._cw.transaction_data['concept_scheme'] = value
-                        break
-        return super(SAEMEditController, self).edit_entity(formparams, multiple)
-
-
 def registration_callback(vreg):
-    vreg.register_all(globals().values(), __name__, (SAEMEditController,))
-    vreg.register_and_replace(SAEMEditController, editcontroller.EditController)
-    from cubes.skos.views import ImportConceptSchemeAction
+    from cubicweb_skos.views import ImportConceptSchemeAction
     vreg.unregister(ImportConceptSchemeAction)
     from cubicweb.web.views import cwsources
     vreg.unregister(cwsources.ManageSourcesAction)
