@@ -23,6 +23,7 @@ from dateutil.parser import parse as parse_date
 from lxml import etree
 import pytz
 
+from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.pyramid.test import PyramidCWTest
 
@@ -32,6 +33,11 @@ from cubicweb_saem_ref import permanent_url
 
 import testutils
 
+
+def setUpModule():
+    testutils.startpgcluster(__file__)
+
+
 EntityInfo = namedtuple('EntityInfo', ['ark', 'url', 'eid'])
 
 
@@ -56,6 +62,8 @@ class OAITestMixin(object):
 
 class OAIComponentTC(CubicWebTC, OAITestMixin):
 
+    configcls = PostgresApptestConfiguration
+
     def test_registered(self):
         with self.admin_access.repo_cnx() as cnx:
             oai = self.oai_component(cnx)
@@ -120,6 +128,8 @@ def setup_organization_units(cnx):
 
 class OAIRequestTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_rset(self):
         """Test `rset` function for exceptions."""
         with self.admin_access.repo_cnx() as cnx:
@@ -154,6 +164,8 @@ def no_validate_xml(method):
 
 
 class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
+
+    configcls = PostgresApptestConfiguration
     settings = {
         # to get clean traceback in tests (instead of in an html error page)
         'cubicweb.bwcompat': False,
