@@ -16,17 +16,25 @@
 """Functional security tests."""
 
 from datetime import date
+
+from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 
 import testutils
 
 
+def setUpModule():
+    testutils.startpgcluster(__file__)
+
+
 class NonManagerUserTC(CubicWebTC):
     """Tests checking that a user in "users" group only can do things.
 
     Most of the times, we do not call any assertion method and only rely on no
     error being raised.
     """
+    configcls = PostgresApptestConfiguration
+
     assertUnauthorized = testutils.assertUnauthorized
 
     login = u'bob'
@@ -279,6 +287,8 @@ class ManagerUserTC(CubicWebTC):
     Most of the times, we do not call any assertion method and only rely on no
     error being raised.
     """
+    configcls = PostgresApptestConfiguration
+
     assertUnauthorized = testutils.assertUnauthorized
 
     def test_create_update_organization(self):
