@@ -29,15 +29,20 @@ from six import text_type
 
 from yams.schema import role_name
 
+from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 
-from cubes.skos.rdfio import default_graph
+from cubicweb_skos.rdfio import default_graph
 
 from cubicweb_saem_ref.views.widgets import process_incomplete_date
 
 import testutils
 
 
+def setUpModule():
+    testutils.startpgcluster(__file__)
+
+
 def eid_from_ark(ark):
     name = ark.rsplit('/', 1)[-1]
     num = ''.join(c for c in name if c.isdigit())
@@ -79,6 +84,8 @@ class SetDateTC(unittest.TestCase):
 
 class FuncViewsTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_citation_view(self):
         with self.admin_access.cnx() as cnx:
             bob = testutils.authority_record(cnx, u'bob')
@@ -109,7 +116,7 @@ class FuncViewsTC(CubicWebTC):
         with self.admin_access.web_request() as req:
             req._ = lambda x: x + u' \xe9'
             authority = req.cnx.create_entity('Organization', name=u'dummy',
-                                              ark=u'123')
+                                              ark=u'123/dummy')
             req.user.cw_set(authority=authority)
             req.cnx.commit()
             output = self.view(regid, req=req, template=None)
@@ -163,8 +170,9 @@ class FuncViewsTC(CubicWebTC):
                                        ark_naa=testutils.naa(cnx))
             scheme.add_concept(u'pop')
             cnx.commit()
-        with self.admin_access.web_request(headers={'Accept': 'application/rdf+xml'}) as req:
-            result = self.app_handle_request(req, 'conceptscheme')
+        with self.admin_access.web_request('conceptscheme',
+                                           headers={'Accept': 'application/rdf+xml'}) as req:
+            result = self.app_handle_request(req)
             with NamedTemporaryFile(delete=False) as fobj:
                 try:
                     fobj.write(result)
@@ -243,6 +251,8 @@ class FuncViewsTC(CubicWebTC):
 
 class SEDAViewsTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_seda_get_related_version(self):
         """Check that we get correct results when asking for `draft`, `published`, `replaced`
         version of a profile."""
@@ -304,6 +314,20 @@ class SEDAViewsTC(CubicWebTC):
 
 class ArkViewsTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
+    def _check_entity_from_path(self, cnx, path, etype, parent_ark=None,
+                                **kwargs):
+        """Make sure an entity with `etype` and `kwargs` attributes values
+        exists and matches ARK identifier found in `path`.
+        """
+        entity = cnx.find(etype, **kwargs).one()
+        self.assertTrue(path.startswith('ark:/'), path)
+        self.assertEqual(entity.ark, path[len('ark:/'):])
+        if parent_ark is not None:
+            self.assertTrue(entity.ark.startswith(parent_ark + '/'),
+                            entity.ark)
+
     def test_ark_authority_record_creation(self):
         with self.admin_access.cnx() as cnx:
             org = testutils.authority_with_naa(cnx)
@@ -314,6 +338,7 @@ class ArkViewsTC(CubicWebTC):
             record = self.vreg['etypes'].etype_class('AuthorityRecord')(req)
             record.eid = 'A'
             fields = {
+                role_name('record_id', 'subject'): u'test',
                 role_name('ark', 'subject'): u'',
                 role_name('agent_kind', 'subject'): str(akind.eid),
                 role_name('ark_naa', 'subject'): str(naa_eid),
@@ -327,9 +352,8 @@ class ArkViewsTC(CubicWebTC):
             req.form = self.fake_form('edition', entity_field_dicts=[(record, fields),
                                                                      (name, name_fields)])
             path = self.expect_redirect_handle_request(req)[0]
-            eid = eid_from_ark(path)
-            record = req.cnx.entity_from_eid(eid)
-            self.assertEqual(record.ark, u'0/r%09d' % eid)
+            self._check_entity_from_path(req, path, 'AuthorityRecord',
+                                         record_id=u'test')
 
     def test_ark_agent_creation(self):
         with self.admin_access.web_request() as req:
@@ -341,21 +365,21 @@ class ArkViewsTC(CubicWebTC):
                       role_name('authority', 'subject'): str(org.eid)}
             req.form = self.fake_form('edition', entity_field_dicts=[(agent, fields)])
             path = self.expect_redirect_handle_request(req)[0]
-            eid = eid_from_ark(path)
-            agent = req.cnx.entity_from_eid(eid)
-            self.assertEqual(agent.ark, u'0/oa%09d' % eid)
+            self._check_entity_from_path(req, path, 'Agent',
+                                         parent_ark=org.ark,
+                                         name=u'007')
 
     def test_ark_scheme_creation(self):
         with self.admin_access.web_request() as req:
             scheme = self.vreg['etypes'].etype_class('ConceptScheme')(req)
             scheme.eid = 'A'
-            fields = {role_name('ark', 'subject'): u'',
+            fields = {role_name('title', 'subject'): u'test',
+                      role_name('ark', 'subject'): u'',
                       role_name('ark_naa', 'subject'): text_type(testutils.naa(req.cnx).eid)}
             req.form = self.fake_form('edition', entity_field_dicts=[(scheme, fields)])
             path = self.expect_redirect_handle_request(req)[0]
-            eid = eid_from_ark(path)
-            scheme = req.cnx.entity_from_eid(eid)
-            self.assertEqual(scheme.ark, u'0/v%09d' % eid)
+            self._check_entity_from_path(req, path, 'ConceptScheme',
+                                         title=u'test')
 
     def test_ark_concept_creation_form(self):
         # test addition of a concept by specifying in_scheme in form
@@ -364,6 +388,7 @@ class ArkViewsTC(CubicWebTC):
             concept = self.vreg['etypes'].etype_class('Concept')(req)
             concept.eid = 'A'
             concept_fields = {role_name('in_scheme', 'subject'): str(scheme.eid),
+                              role_name('definition', 'subject'): u'thing',
                               role_name('ark', 'subject'): u''}
             label = self.vreg['etypes'].etype_class('Label')(req)
             label.eid = 'B'
@@ -372,28 +397,9 @@ class ArkViewsTC(CubicWebTC):
             req.form = self.fake_form('edition', entity_field_dicts=[(concept, concept_fields),
                                                                      (label, label_fields)])
             path = self.expect_redirect_handle_request(req)[0]
-            eid = eid_from_ark(path)
-            concept = req.cnx.entity_from_eid(eid)
-            self.assertEqual(concept.ark, u'0/c%09d' % eid)
-
-    def test_ark_concept_creation_linkto(self):
-        # test addition of a concept by specifying in_scheme with __linkto
-        with self.admin_access.web_request() as req:
-            scheme = req.cnx.create_entity('ConceptScheme', ark_naa=testutils.naa(req.cnx))
-            concept = self.vreg['etypes'].etype_class('Concept')(req)
-            concept.eid = 'A'
-            concept_fields = {}
-            label = self.vreg['etypes'].etype_class('Label')(req)
-            label.eid = 'B'
-            label_fields = {role_name('label', 'subject'): u'Goodby',
-                            role_name('label_of', 'subject'): 'A'}
-            req.form = self.fake_form('edition', entity_field_dicts=[(concept, concept_fields),
-                                                                     (label, label_fields)])
-            req.form['__linkto'] = 'in_scheme:%s:subject' % scheme.eid
-            path = self.expect_redirect_handle_request(req)[0]
-            eid = eid_from_ark(path)
-            concept = req.cnx.entity_from_eid(eid)
-            self.assertEqual(concept.ark, u'0/c%09d' % eid)
+            self._check_entity_from_path(req, path, 'Concept',
+                                         parent_ark=scheme.ark,
+                                         definition=u'thing')
 
     def test_ark_url_rewrite(self):
         with self.admin_access.web_request() as req:
@@ -404,6 +410,8 @@ class ArkViewsTC(CubicWebTC):
 
 class AssignArkWebServiceTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_not_authenticated(self):
         with self.new_access('anon').web_request(headers={'Accept': 'application/json'},
                                                  method='POST') as req:
@@ -413,8 +421,9 @@ class AssignArkWebServiceTC(CubicWebTC):
 
     def test_authenticated_missing_organization(self):
         with self.admin_access.web_request(
+                'ark',
                 headers={'Accept': 'application/json'}, method='POST') as req:
-            result = self.app_handle_request(req, 'ark')
+            result = self.app_handle_request(req)
             self.assertEqual(json.loads(result),
                              [{'error': 'Missing required "organization" query parameter.'}])
 
@@ -452,7 +461,7 @@ class AssignArkWebServiceTC(CubicWebTC):
     def test_authenticated_organization_has_no_naa_method_post(self):
         with self.admin_access.cnx() as cnx:
             org_ark = cnx.create_entity(
-                'Organization', name=u'dummy', ark=u'123').ark
+                'Organization', name=u'dummy', ark=u'123/dummy').ark
             cnx.commit()
         bad_params = {'organization': org_ark}
         with self.admin_access.web_request(
@@ -467,23 +476,31 @@ class AssignArkWebServiceTC(CubicWebTC):
         with self.admin_access.cnx() as cnx:
             org_ark = testutils.authority_with_naa(cnx).ark
             cnx.commit()
+
+        def check_ark(response_body):
+            json_response = json.loads(result)
+            self.assertEqual(len(json_response), 1)
+            self.assertEqual(list(json_response[0].keys()), ['ark'])
+            ark = json_response[0]['ark']
+            self.assertTrue(testutils.ARK_RGX.match(ark), ark)
+
         params = {'organization': org_ark}
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'},
                 method='POST', **params) as req:
             result = self.app_handle_request(req, 'ark')
-            self.assertEqual(json.loads(result),
-                             [{'ark': '0/a000000001'}])
+            check_ark(result)
         params = {'organization': 'ark:/' + org_ark}
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'},
                 method='POST', **params) as req:
             result = self.app_handle_request(req, 'ark')
-            self.assertEqual(json.loads(result),
-                             [{'ark': '0/a000000002'}])
+            check_ark(result)
 
 
 class ListArchivalUnitsServiceTC(CubicWebTC):
+
+    configcls = PostgresApptestConfiguration
     maxDiff = None
 
     def test_ok(self):
@@ -517,57 +534,63 @@ class ListArchivalUnitsServiceTC(CubicWebTC):
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'}) as req:
             result = json.loads(self.app_handle_request(req, 'archival-units'))
+            expected = [
+                {
+                    'ark': archival_unit.ark,
+                    'name': 'Archival Dptmt',
+                    'state': 'published',
+                    'url': archival_unit.absolute_url(),
+                    'authority': {
+                        'ark': org.ark,
+                        'name': org.name,
+                        'url': org.absolute_url(),
+                    },
+                    'deposit-units': [
+                        {
+                            'ark': dep_unit.ark,
+                            'name': dep_unit.name,
+                            'state': 'published',
+                            'url': dep_unit.absolute_url(),
+                            'authority': {
+                                'ark': org.ark,
+                                'name': org.name,
+                                'url': org.absolute_url(),
+                            },
+                        },
+                        {
+                            'ark': deprecated_dep_unit.ark,
+                            'name': deprecated_dep_unit.name,
+                            'state': 'deprecated',
+                            'url': deprecated_dep_unit.absolute_url(),
+                            'authority': {
+                                'ark': org.ark,
+                                'name': org.name,
+                                'url': org.absolute_url(),
+                            },
+                        },
+                        {
+                            'ark': dep2_unit.ark,
+                            'name': dep2_unit.name,
+                            'state': 'published',
+                            'url': dep2_unit.absolute_url(),
+                            'authority': {
+                                'ark': org2.ark,
+                                'name': org2.name,
+                                'url': org2.absolute_url(),
+                            },
+                        },
+                    ],
+                },
+            ]
             result[0]['deposit-units'].sort()
-            self.assertEqual(
-                result,
-                [{'ark': archival_unit.ark,
-                  'name': 'Archival Dptmt',
-                  'state': 'published',
-                  'url': archival_unit.absolute_url(),
-                  'authority': {
-                      'ark': org.ark,
-                      'name': org.name,
-                      'url': org.absolute_url(),
-                  },
-                  'deposit-units': [
-                      {
-                          'ark': dep_unit.ark,
-                          'name': dep_unit.name,
-                          'state': 'published',
-                          'url': dep_unit.absolute_url(),
-                          'authority': {
-                              'ark': org.ark,
-                              'name': org.name,
-                              'url': org.absolute_url(),
-                          },
-                      },
-                      {
-                          'ark': deprecated_dep_unit.ark,
-                          'name': deprecated_dep_unit.name,
-                          'state': 'deprecated',
-                          'url': deprecated_dep_unit.absolute_url(),
-                          'authority': {
-                              'ark': org.ark,
-                              'name': org.name,
-                              'url': org.absolute_url(),
-                          },
-                      },
-                      {
-                          'ark': dep2_unit.ark,
-                          'name': dep2_unit.name,
-                          'state': 'published',
-                          'url': dep2_unit.absolute_url(),
-                          'authority': {
-                              'ark': org2.ark,
-                              'name': org2.name,
-                              'url': org2.absolute_url(),
-                          },
-                      },
-                  ]}])
+            expected[0]['deposit-units'].sort()
+            self.assertEqual(result, expected)
 
 
 class TimelineViewsTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_timeline_json(self):
         with self.admin_access.cnx() as cnx:
             ar1 = testutils.authority_record(
