@@ -18,6 +18,7 @@
 from __future__ import print_function
 
 from os.path import join, dirname, exists
+import re
 import sys
 
 from doctest import Example
@@ -31,6 +32,8 @@ from cubicweb import NoResultError, devtools
 from cubicweb.devtools import testlib
 
 from cubicweb_seda import testutils as seda_testutils
+from cubicweb_saem_ref import ark
+
 
 # make some names them appear in this module namespace to ease test API
 assertValidationError = seda_testutils.assertValidationError
@@ -116,6 +119,42 @@ def authority_with_naa(cnx, name=u'Default authority', **kwargs):
     return authority
 
 
+ARK_URI_RGX = re.compile(
+    r'^ark:/0/%s.{%d}%s(/.{%d})?$'
+    % (ark.ARK_PREFIX,
+       ark.ARK_NAME_LENGTH - len(ark.ARK_PREFIX) - len(ark.ARK_CONTROLCHAR),
+       ark.ARK_CONTROLCHAR, ark.ARK_QUALIFIER_LENGTH),
+)
+
+
+ARK_RGX = re.compile(
+    r'^0/%s.{%d}%s(/.{%d})?$'
+    % (ark.ARK_PREFIX,
+       ark.ARK_NAME_LENGTH - len(ark.ARK_PREFIX) - len(ark.ARK_CONTROLCHAR),
+       ark.ARK_CONTROLCHAR, ark.ARK_QUALIFIER_LENGTH),
+)
+
+
+ARK_NAME_RGX = re.compile(
+    r'^%s.{%d}%s$'
+    % (ark.ARK_PREFIX,
+       ark.ARK_NAME_LENGTH - len(ark.ARK_PREFIX) - len(ark.ARK_CONTROLCHAR),
+       ark.ARK_CONTROLCHAR),
+)
+
+
+def match_ark_uri(text):
+    return ARK_URI_RGX.match(text)
+
+
+def match_ark(text):
+    return ARK_RGX.match(text)
+
+
+def match_ark_name(text):
+    return ARK_NAME_RGX.match(text)
+
+
 def setup_scheme(cnx, title, *labels, **kwargs):
     """Return info new concept scheme"""
     scheme = cnx.create_entity('ConceptScheme', title=title, ark_naa=naa(cnx), **kwargs)
@@ -167,13 +206,19 @@ class XmlTestMixin(object):
         xmlschema.assertValid(xml_data)
 
 
+def startpgcluster(pyfile):
+    """Let PostgreSQL cluster be started only once per process and stopped at exit.
+    """
+    if devtools.DEFAULT_PSQL_SOURCES['system']['db-host'] == 'REPLACEME':
+        devtools.startpgcluster(pyfile)
+        import atexit
+        atexit.register(devtools.stoppgcluster, pyfile)
+
+
 # speed up tests by using a global configuration ###################################################
 _CONFIGS = {}
 
 
-orig_setup_class = testlib.CubicWebTC.setUpClass
-
-
 @monkeypatch(testlib.CubicWebTC, methodname='setUpClass')
 @classmethod
 def setUpClass(cls):
@@ -193,13 +238,6 @@ def setUpClass(cls):
     cls.config = config
 
 
-def startpgcluster(pyfile):
-    if devtools.DEFAULT_PSQL_SOURCES['system']['db-host'] == 'REPLACEME':
-        devtools.startpgcluster(pyfile)
-        import atexit
-        atexit.register(devtools.stoppgcluster, pyfile)
-
-
 class _HCache(dict):
     """Original devtools handler cache prevent caching of several configurations, but that's
     what we're trying to achieve.
