@@ -21,17 +21,26 @@ import unittest
 
 import pytz
 
+from cubicweb import ValidationError
+from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 
 from cubicweb_saem_ref.hooks import extract_ark
 
 import testutils
 
+
+def setUpModule():
+    testutils.startpgcluster(__file__)
+
+
 YESTERDAY = datetime.now(tz=pytz.utc) - timedelta(days=1)
 
 
 class SAEMRefHooksTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def assertMDNow(self, entity):
         entity.cw_clear_all_caches()
         self.assertAlmostEqual(mktime(entity.modification_date.timetuple()),
@@ -201,68 +210,6 @@ class SAEMRefHooksTC(CubicWebTC):
             self.assertEqual(arelation.association_from[0], alice)
             self.failIf(cnx.execute('Any X WHERE X eid %(x)s', {'x': exturi.eid}))
 
-    def test_ark_generation_authorityrecord(self):
-        with self.admin_access.repo_cnx() as cnx:
-            agent = testutils.authority_record(cnx, u'bob')
-            cnx.commit()
-            self.assertEqual(agent.ark, '0/r%09d' % agent.eid)
-            self.assertEqual(agent.cwuri, 'ark:/0/r%09d' % agent.eid)
-            agent = testutils.authority_record(cnx, u'john', ark=u'authority/123456')
-            cnx.commit()
-            self.assertEqual(agent.ark, 'authority/123456')
-            self.assertEqual(agent.cwuri, 'ark:/authority/123456')
-            agent = testutils.authority_record(cnx, u'alf', cwuri=u'http://someuri/someagent')
-            cnx.commit()
-            self.assertEqual(agent.ark, '0/r%09d' % agent.eid)
-            self.assertEqual(agent.cwuri, 'http://someuri/someagent')
-
-    def test_ark_generation_seda_profile(self):
-        with self.admin_access.repo_cnx() as cnx:
-            profile = testutils.setup_profile(cnx)
-            self.assertEqual(profile.ark, '0/p{0:09d}'.format(profile.eid))
-            self.assertEqual(profile.cwuri, 'ark:/0/p{0:09d}'.format(profile.eid))
-
-    def test_ark_generation_seda_profile_ark_given(self):
-        with self.admin_access.repo_cnx() as cnx:
-            profile = testutils.setup_profile(cnx, ark=u'authority/124')
-            self.assertEqual(profile.ark, 'authority/124')
-            self.assertEqual(profile.cwuri, 'ark:/authority/124')
-
-    def test_ark_generation_seda_profile_with_cwuri(self):
-        with self.admin_access.repo_cnx() as cnx:
-            profile = testutils.setup_profile(
-                cnx, cwuri=u'http://example.org/profile/125')
-            self.assertEqual(profile.ark, '0/p{0:09d}'.format(profile.eid))
-            self.assertEqual(profile.cwuri, 'http://example.org/profile/125')
-
-    def test_ark_generation_concept(self):
-        with self.admin_access.repo_cnx() as cnx:
-            scheme = cnx.create_entity('ConceptScheme', ark_naa=testutils.naa(cnx))
-            concept = scheme.add_concept(u'some object')
-            cnx.commit()
-            self.assertEqual(scheme.ark, '0/v%09d' % scheme.eid)
-            self.assertEqual(scheme.cwuri,
-                             'ark:/0/v%09d' % scheme.eid)
-            self.assertEqual(concept.ark, '0/c%09d' % concept.eid)
-            self.assertEqual(concept.cwuri,
-                             'ark:/0/c%09d' % concept.eid)
-            scheme = cnx.create_entity('ConceptScheme', cwuri=u'http://someuri/somescheme',
-                                       ark_naa=testutils.naa(cnx))
-            concept = scheme.add_concept(u'some object', cwuri=u'http://someuri/someconcept')
-            cnx.commit()
-            self.assertEqual(scheme.ark, '0/v%09d' % scheme.eid)
-            self.assertEqual(scheme.cwuri, 'http://someuri/somescheme')
-            self.assertEqual(concept.ark, '0/c%09d' % concept.eid)
-            self.assertEqual(concept.cwuri, 'http://someuri/someconcept')
-            scheme = cnx.create_entity('ConceptScheme', cwuri=u'http://dcf/res/ark:/67717/Matiere',
-                                       ark_naa=testutils.naa(cnx))
-            concept = scheme.add_concept(u'some object', cwuri=u'http://dcf/res/ark:/67717/1234')
-            cnx.commit()
-            self.assertEqual(scheme.ark, '67717/Matiere')
-            self.assertEqual(scheme.cwuri, 'http://dcf/res/ark:/67717/Matiere')
-            self.assertEqual(concept.ark, '67717/1234')
-            self.assertEqual(concept.cwuri, 'http://dcf/res/ark:/67717/1234')
-
     def test_user_email(self):
         # EmailAddress belong to the Organisation graph, hence may conflict with hooks when linked
         # to a user. This is a non-regression test checking that no error is raised on attempt to
@@ -273,8 +220,116 @@ class SAEMRefHooksTC(CubicWebTC):
             cnx.commit()
 
 
+class ARKGenerationHooksTC(CubicWebTC):
+
+    configcls = PostgresApptestConfiguration
+
+    def _check_ark(self, entity, parent_ark=None):
+        self.assertTrue(testutils.match_ark(entity.ark), entity.ark)
+        if parent_ark is not None:
+            self.assertTrue(entity.ark.startswith(parent_ark + '/'),
+                            (parent_ark, entity.ark))
+
+    def _check_ark_and_cwuri(self, entity, **kwargs):
+        self._check_ark(entity, **kwargs)
+        self.assertTrue(testutils.match_ark_uri(entity.cwuri), entity.cwuri)
+
+    def test_external_ark_invalid(self):
+        with self.admin_access.cnx() as cnx:
+            for ark in [
+                u'string/name',  # NAAN is not a number
+                u'123',  # Missing Name
+            ]:
+                with self.subTest(ark=ark):
+                    with self.assertRaises(ValidationError) as cm:
+                        testutils.authority_record(cnx, u'bob', ark=ark)
+                    self.assertIn('malformatted ARK idenfitier', str(cm.exception))
+
+    def test_external_ark_duplicated(self):
+        ark = '1/bob/thefirst'
+        with self.admin_access.cnx() as cnx:
+            cnx.create_entity('Agent', name=u'bob', ark=ark)
+            with self.assertRaises(ValidationError) as cm:
+                cnx.create_entity('ConceptScheme', ark=ark)
+            self.assertIn('already exists', str(cm.exception))
+
+    def test_external_ark_duplicated_generated(self):
+        with self.admin_access.cnx() as cnx:
+            authority = testutils.authority_with_naa(cnx)
+            agent = cnx.create_entity('Agent', name=u'bob', authority=authority)
+            with self.assertRaises(ValidationError) as cm:
+                cnx.create_entity('ConceptScheme', ark=agent.ark)
+            self.assertIn('already exists', str(cm.exception))
+
+    def test_ark_generation_authorityrecord(self):
+        with self.admin_access.repo_cnx() as cnx:
+            agent = testutils.authority_record(cnx, u'bob')
+            cnx.commit()
+            self._check_ark_and_cwuri(agent)
+            agent = testutils.authority_record(cnx, u'john', ark=u'999/123456')
+            cnx.commit()
+            self.assertEqual(agent.ark, '999/123456')
+            self.assertEqual(agent.cwuri, 'ark:/999/123456')
+            agent = testutils.authority_record(cnx, u'alf', cwuri=u'http://someuri/someagent')
+            cnx.commit()
+            self._check_ark(agent)
+            self.assertEqual(agent.cwuri, 'http://someuri/someagent')
+
+    def test_ark_generation_seda_profile(self):
+        with self.admin_access.repo_cnx() as cnx:
+            profile = testutils.setup_profile(cnx)
+            self._check_ark_and_cwuri(profile)
+
+    def test_ark_generation_seda_profile_ark_given(self):
+        with self.admin_access.repo_cnx() as cnx:
+            profile = testutils.setup_profile(cnx, ark=u'99/124')
+            self.assertEqual(profile.ark, '99/124')
+            self.assertEqual(profile.cwuri, 'ark:/99/124')
+
+    def test_ark_generation_seda_profile_with_cwuri(self):
+        with self.admin_access.repo_cnx() as cnx:
+            profile = testutils.setup_profile(
+                cnx, cwuri=u'http://example.org/profile/125')
+            self._check_ark(profile)
+            self.assertEqual(profile.cwuri, 'http://example.org/profile/125')
+
+    def test_ark_generation_concept(self):
+        with self.admin_access.repo_cnx() as cnx:
+            scheme = cnx.create_entity('ConceptScheme', ark_naa=testutils.naa(cnx))
+            concept = scheme.add_concept(u'some object')
+            cnx.commit()
+            self._check_ark_and_cwuri(scheme)
+            self._check_ark_and_cwuri(concept, parent_ark=scheme.ark)
+            scheme = cnx.create_entity('ConceptScheme', cwuri=u'http://someuri/somescheme',
+                                       ark_naa=testutils.naa(cnx))
+            concept = scheme.add_concept(u'some object', cwuri=u'http://someuri/someconcept')
+            cnx.commit()
+            self._check_ark(scheme)
+            self.assertEqual(scheme.cwuri, 'http://someuri/somescheme')
+            self._check_ark(concept, scheme.ark)
+            self.assertEqual(concept.cwuri, 'http://someuri/someconcept')
+            scheme = cnx.create_entity('ConceptScheme', cwuri=u'http://dcf/res/ark:/67717/Matiere',
+                                       ark_naa=testutils.naa(cnx))
+            concept = scheme.add_concept(u'some object', cwuri=u'http://dcf/res/ark:/67717/1234')
+            cnx.commit()
+            self.assertEqual(scheme.ark, '67717/Matiere')
+            self.assertEqual(scheme.cwuri, 'http://dcf/res/ark:/67717/Matiere')
+            self.assertEqual(concept.ark, '67717/1234')
+            self.assertEqual(concept.cwuri, 'http://dcf/res/ark:/67717/1234')
+
+    def test_ark_generation_organization_unit(self):
+        with self.admin_access.cnx() as cnx:
+            authority = testutils.authority_with_naa(cnx)
+            orgunit = testutils.organization_unit(
+                cnx, u'test', authority=authority)
+            cnx.commit()
+            self._check_ark(orgunit, authority.ark)
+
+
 class AuthorityRecordHookTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def setup_database(self):
         with self.admin_access.cnx() as cnx:
             self.org_eid = testutils.authority_with_naa(cnx).eid
@@ -305,6 +360,8 @@ class AuthorityRecordHookTC(CubicWebTC):
 
 class ExtractArkTC(unittest.TestCase):
 
+    configcls = PostgresApptestConfiguration
+
     def test_ok(self):
         self.assertEqual(extract_ark('http://dcf/res/ark:/67717/1234'), '67717/1234')
         self.assertEqual(extract_ark('http://dcf/res/ark:/67717/1234#something'), '67717/1234')
@@ -319,6 +376,8 @@ class ExtractArkTC(unittest.TestCase):
 
 class EntityLifeCycleTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def setup_database(self):
         with self.admin_access.repo_cnx() as cnx:
             bob = self.create_user(cnx, u'bob',
@@ -553,7 +612,9 @@ class EntityLifeCycleTC(CubicWebTC):
 
 class SEDAArchiveTransferHooksTC(CubicWebTC):
 
-    def test_profile_deprecated(self):
+    configcls = PostgresApptestConfiguration
+
+    def test_profile_deprecated_by_published_successor(self):
         """Test hook deprecating a SEDA Profile upon successor publication."""
         with self.admin_access.repo_cnx() as cnx:
             profile = testutils.setup_profile(cnx)
@@ -572,6 +633,21 @@ class SEDAArchiveTransferHooksTC(CubicWebTC):
             profile.cw_clear_all_caches()
             self.assertEqual(workflow.state, 'deprecated')
 
+    def test_profile_deprecated_unlinked_from_organization_unit(self):
+        with self.admin_access.cnx() as cnx:
+            profile = testutils.setup_profile(cnx)
+            organization_unit = testutils.organization_unit(
+                cnx, u'org', archival_roles=[u'deposit'])
+            cnx.commit()
+            workflow = profile.cw_adapt_to('IWorkflowable')
+            workflow.fire_transition('publish')
+            cnx.commit()
+            organization_unit.cw_set(use_profile=profile)
+            cnx.commit()
+            workflow.fire_transition('deprecate')
+            cnx.commit()
+            self.assertFalse(organization_unit.use_profile)
+
 
 if __name__ == '__main__':
     unittest.main()
